@@ -19,6 +19,7 @@
 # - Ralph Vigne <ralph.vigne@cern.ch>, 2013-2015
 # - Cedric Serfon <cedric.serfon@cern.ch>, 2014-2016
 # - Martin Barisits <martin.barisits@cern.ch>, 2014-2018
+# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
 #
 # PY3K COMPATIBLE
 
@@ -43,13 +44,31 @@ from rucio.client.subscriptionclient import SubscriptionClient
 from rucio.client.configclient import ConfigClient
 from rucio.client.touchclient import TouchClient
 from rucio.client.credentialclient import CredentialClient
+from rucio.client.diracclient import DiracClient
 
 
-class Client(AccountClient, AccountLimitClient, MetaClient, PingClient, ReplicaClient, RequestClient, RSEClient, ScopeClient, DIDClient, RuleClient, SubscriptionClient, LockClient, ConfigClient, TouchClient, ImportClient, ExportClient, CredentialClient):
+class Client(AccountClient,
+             AccountLimitClient,
+             MetaClient,
+             PingClient,
+             ReplicaClient,
+             RequestClient,
+             RSEClient,
+             ScopeClient,
+             DIDClient,
+             RuleClient,
+             SubscriptionClient,
+             LockClient,
+             ConfigClient,
+             TouchClient,
+             ImportClient,
+             ExportClient,
+             CredentialClient,
+             DiracClient):
 
     """Main client class for accessing Rucio resources. Handles the authentication."""
 
-    def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=600, user_agent='rucio-clients'):
+    def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=600, user_agent='rucio-clients', vo=None):
         """
         Constructor for the Rucio main client class.
 
@@ -60,5 +79,6 @@ class Client(AccountClient, AccountLimitClient, MetaClient, PingClient, ReplicaC
         :param auth_type: the type of authentication to use (e.g. userpass, x509 ...)
         :param creds: credentials needed for authentication.
         :param timeout: Float describes the timeout of the request (in seconds).
+        :param vo: The vo that the client will interact with.
         """
-        super(Client, self).__init__(rucio_host=rucio_host, auth_host=auth_host, account=account, ca_cert=ca_cert, auth_type=auth_type, creds=creds, timeout=timeout, user_agent=user_agent)
+        super(Client, self).__init__(rucio_host=rucio_host, auth_host=auth_host, account=account, ca_cert=ca_cert, auth_type=auth_type, creds=creds, timeout=timeout, user_agent=user_agent, vo=vo)
