@@ -1,4 +1,5 @@
-# Copyright 2012-2020 CERN for the benefit of the ATLAS collaboration.
+# -*- coding: utf-8 -*-
+# Copyright 2012-2020 CERN
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,7 +18,7 @@
 # - Mario Lassnig <mario.lassnig@cern.ch>, 2012-2019
 # - Angelos Molfetas <Angelos.Molfetas@cern.ch>, 2012
 # - Thomas Beermann <thomas.beermann@cern.ch>, 2012
-# - Joaquin Bogado <jbogado@linti.unlp.edu.ar>, 2014-2018
+# - Joaquín Bogado <jbogado@linti.unlp.edu.ar>, 2014-2018
 # - Cheng-Hsi Chao <cheng-hsi.chao@cern.ch>, 2014
 # - Cedric Serfon <cedric.serfon@cern.ch>, 2015
 # - Martin Barisits <martin.barisits@cern.ch>, 2015-2019
@@ -28,15 +29,17 @@
 # - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
 # - Eli Chadwick <eli.chadwick@stfc.ac.uk>, 2020
 # - Patrick Austin <patrick.austin@stfc.ac.uk>, 2020
-#
-# PY3K COMPATIBLE
+# - Tomas Javurek <tomas.javurek@cern.ch>, 2020
 
 from __future__ import print_function
 
+import os
 import re
 import unittest
 from os import remove, unlink, listdir, rmdir, stat, path, environ
 
+import pytest
+
 from rucio.client.accountlimitclient import AccountLimitClient
 from rucio.client.didclient import DIDClient
 from rucio.client.replicaclient import ReplicaClient
@@ -45,7 +48,6 @@ from rucio.client.ruleclient import RuleClient
 from rucio.common.config import config_get, config_get_bool
 from rucio.common.types import InternalScope, InternalAccount
 from rucio.common.utils import generate_uuid, get_tmp_dir, md5, render_json
-from rucio.daemons.abacus import account as abacus_account
 from rucio.rse import rsemanager as rsemgr
 from rucio.tests.common import execute, account_name_generator, rse_name_generator, file_generator, scope_name_generator
 
@@ -104,7 +106,7 @@ class TestBinRucio(unittest.TestCase):
         print(self.marker + cmd)
         exitcode, out, err = execute(cmd)
         print(out, err)
-        assert 'Could not load Rucio configuration file' in err and err.rstrip().endswith('errconfig')
+        assert 'Could not load Rucio configuration file' in err and re.match('.*errconfig.*$', err, re.DOTALL)
 
     def test_add_account(self):
         """CLIENT(ADMIN): Add account"""
@@ -323,10 +325,12 @@ class TestBinRucio(unittest.TestCase):
         if environ.get('SUITE', 'all') != 'client':
             from rucio.db.sqla import session, models
             db_session = session.get_session()
-            db_session.query(models.RSEFileAssociation).filter_by(name=tmp_file1_name, scope=InternalScope(self.user, **self.vo)).delete()
+            internal_scope = InternalScope(self.user, **self.vo)
+            db_session.query(models.RSEFileAssociation).filter_by(name=tmp_file1_name, scope=internal_scope).delete()
             db_session.query(models.ReplicaLock).delete()
-            db_session.query(models.ReplicationRule).filter_by(name=tmp_file1_name, scope=InternalScope(self.user, **self.vo)).delete()
-            db_session.query(models.DataIdentifier).filter_by(name=tmp_file1_name, scope=InternalScope(self.user, **self.vo)).delete()
+            db_session.query(models.ReplicationRule).filter_by(name=tmp_file1_name, scope=internal_scope).delete()
+            db_session.query(models.DidMeta).filter_by(name=tmp_file1_name, scope=internal_scope).delete()
+            db_session.query(models.DataIdentifier).filter_by(name=tmp_file1_name, scope=internal_scope).delete()
             db_session.commit()
             tmp_file4 = file_generator()
             checksum_tmp_file4 = md5(tmp_file4)
@@ -734,11 +738,13 @@ class TestBinRucio(unittest.TestCase):
         # Use filter and metalink option
         cmd = 'rucio download --scope mock --filter size=1 --metalink=test'
         exitcode, out, err = execute(cmd)
+        print(out, err)
         assert 'Arguments filter and metalink cannot be used together' in err
 
         # Use did and metalink option
         cmd = 'rucio download --metalink=test mock:test'
         exitcode, out, err = execute(cmd)
+        print(out, err)
         assert 'Arguments dids and metalink cannot be used together' in err
 
         # Download only with metalink file
@@ -746,14 +752,17 @@ class TestBinRucio(unittest.TestCase):
         tmp_file_name = tmp_file[5:]
         cmd = 'rucio upload --rse {0} --scope {1} {2}'.format(self.def_rse, scope, tmp_file)
         exitcode, out, err = execute(cmd)
+        print(out, err)
         replica_file = ReplicaClient().list_replicas([{'scope': scope, 'name': tmp_file_name}], metalink=True)
         with open(metalink_file_path, 'w+') as metalink_file:
             metalink_file.write(replica_file)
         cmd = 'rucio download --dir /tmp --metalink {0}'.format(metalink_file_path)
         exitcode, out, err = execute(cmd)
+        print(out, err)
         remove(metalink_file_path)
         cmd = 'ls /tmp/{0}'.format(scope)
         exitcode, out, err = execute(cmd)
+        print(out, err)
         assert re.search(tmp_file_name, out) is not None
 
     def test_download_succeeds_md5only(self):
@@ -1337,37 +1346,39 @@ class TestBinRucio(unittest.TestCase):
         self.account_client.set_local_account_limit(account, rse, -1)
         self.account_client.set_global_account_limit(account, rse_exp, -1)
 
+    @pytest.mark.skipif('SUITE' in os.environ and os.environ['SUITE'] == 'client', reason='uses abacus daemon and core functions')
     def test_list_account_usage(self):
         """ CLIENT (USER): list account usage. """
-        if environ.get('SUITE', 'all') != 'client':
-            from rucio.db.sqla import session, models
-            from rucio.core.account_counter import increase
-            db_session = session.get_session()
-            db_session.query(models.AccountUsage).delete()
-            db_session.query(models.AccountLimit).delete()
-            db_session.query(models.AccountGlobalLimit).delete()
-            db_session.query(models.UpdatedAccountCounter).delete()
-            db_session.commit()
-            rse = 'MOCK4'
-            rse_id = self.rse_client.get_rse(rse)['id']
-            rse_exp = 'MOCK|MOCK4'
-            account = 'root'
-            usage = 4
-            local_limit = 10
-            local_left = local_limit - usage
-            global_limit = 20
-            global_left = global_limit - usage
-            self.account_client.set_local_account_limit(account, rse, local_limit)
-            self.account_client.set_global_account_limit(account, rse_exp, global_limit)
-            increase(rse_id, InternalAccount(account, **self.vo), 1, usage)
-            abacus_account.run(once=True)
-            cmd = 'rucio list-account-usage {0}'.format(account)
-            exitcode, out, err = execute(cmd)
-            assert re.search('.*{0}.*{1}.*{2}.*{3}'.format(rse, usage, local_limit, local_left), out) is not None
-            assert re.search('.*{0}.*{1}.*{2}.*{3}'.format(rse_exp, usage, global_limit, global_left), out) is not None
-            cmd = 'rucio list-account-usage --rse {0} {1}'.format(rse, account)
-            exitcode, out, err = execute(cmd)
-            assert re.search('.*{0}.*{1}.*{2}.*{3}'.format(rse, usage, local_limit, local_left), out) is not None
-            assert re.search('.*{0}.*{1}.*{2}.*{3}'.format(rse_exp, usage, global_limit, global_left), out) is not None
-            self.account_client.set_local_account_limit(account, rse, -1)
-            self.account_client.set_global_account_limit(account, rse_exp, -1)
+        from rucio.db.sqla import session, models
+        from rucio.core.account_counter import increase
+        from rucio.daemons.abacus import account as abacus_account
+
+        db_session = session.get_session()
+        db_session.query(models.AccountUsage).delete()
+        db_session.query(models.AccountLimit).delete()
+        db_session.query(models.AccountGlobalLimit).delete()
+        db_session.query(models.UpdatedAccountCounter).delete()
+        db_session.commit()
+        rse = 'MOCK4'
+        rse_id = self.rse_client.get_rse(rse)['id']
+        rse_exp = 'MOCK|MOCK4'
+        account = 'root'
+        usage = 4
+        local_limit = 10
+        local_left = local_limit - usage
+        global_limit = 20
+        global_left = global_limit - usage
+        self.account_client.set_local_account_limit(account, rse, local_limit)
+        self.account_client.set_global_account_limit(account, rse_exp, global_limit)
+        increase(rse_id, InternalAccount(account, **self.vo), 1, usage)
+        abacus_account.run(once=True)
+        cmd = 'rucio list-account-usage {0}'.format(account)
+        exitcode, out, err = execute(cmd)
+        assert re.search('.*{0}.*{1}.*{2}.*{3}'.format(rse, usage, local_limit, local_left), out) is not None
+        assert re.search('.*{0}.*{1}.*{2}.*{3}'.format(rse_exp, usage, global_limit, global_left), out) is not None
+        cmd = 'rucio list-account-usage --rse {0} {1}'.format(rse, account)
+        exitcode, out, err = execute(cmd)
+        assert re.search('.*{0}.*{1}.*{2}.*{3}'.format(rse, usage, local_limit, local_left), out) is not None
+        assert re.search('.*{0}.*{1}.*{2}.*{3}'.format(rse_exp, usage, global_limit, global_left), out) is not None
+        self.account_client.set_local_account_limit(account, rse, -1)
+        self.account_client.set_global_account_limit(account, rse_exp, -1)
