@@ -1,34 +1,46 @@
-# Copyright European Organization for Nuclear Research (CERN)
+# -*- coding: utf-8 -*-
+# Copyright 2014-2020 CERN for the benefit of the ATLAS collaboration.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
-# You may not use this file except in compliance with the License.
+# you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# http://www.apache.org/licenses/LICENSE-2.0
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 #
 # Authors:
-# - Wen Guan, <wguan@cern.ch>, 2014
+# - Wen Guan <wen.guan@cern.ch>, 2014
+# - Vincent Garonne <vincent.garonne@cern.ch>, 2014-2015
+# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
 
 import json
 import os
 import shutil
 import tempfile
-
+import unittest
 from uuid import uuid4 as uuid
 
-from nose.tools import raises
+import pytest
 
 from rucio.common import exception
-from rucio.rse import rsemanager as mgr
-from rsemgr_api_test import MgrTestCases
 from rucio.common.utils import execute
+from rucio.rse import rsemanager as mgr
+from rucio.tests.common import skip_rse_tests_with_accounts
+from rucio.tests.rsemgr_api_test import MgrTestCases
 
 
-class TestRseGFAL2():
+@skip_rse_tests_with_accounts
+class TestRseGFAL2(unittest.TestCase):
     tmpdir = None
     user = None
 
     @classmethod
-    def setupClass(cls):
+    def setUpClass(cls):
         """GFAL2 (RSE/PROTOCOLS): Creating necessary directories and files """
         # Creating local files
         cls.tmpdir = tempfile.mkdtemp()
@@ -36,7 +48,7 @@ class TestRseGFAL2():
 
         with open("%s/data.raw" % cls.tmpdir, "wb") as out:
             out.seek((1024 * 1024) - 1)  # 1 MB
-            out.write('\0')
+            out.write(b'\0')
         for f in MgrTestCases.files_local:
             shutil.copy('%s/data.raw' % cls.tmpdir, '%s/%s' % (cls.tmpdir, f))
 
@@ -76,7 +88,7 @@ class TestRseGFAL2():
             execute(cmd)
 
     @classmethod
-    def teardownClass(cls):
+    def tearDownClass(cls):
         """GFAL2 (RSE/PROTOCOLS): Removing created directorie s and files"""
         with open('etc/rse_repository.json') as f:
             data = json.load(f)
@@ -118,7 +130,7 @@ class TestRseGFAL2():
             clean_cmd = 'srmrmdir -2 --debug=false -retry_num=0 -recursive %s%s/%s/%s' % (srm_path, prefix, directory, cls.user)
             execute(clean_cmd)
 
-    def setup(self):
+    def setUp(self):
         """GFAL2 (RSE/PROTOCOLS): Creating Mgr-instance """
         self.tmpdir = TestRseGFAL2.tmpdir
         self.rse_id = 'FZK-LCG2_SCRATCHDISK'
@@ -139,20 +151,20 @@ class TestRseGFAL2():
         """GFAL2 (RSE/PROTOCOLS): Get a single file from storage providing PFN (Success)"""
         self.mtc.test_get_mgr_ok_single_pfn()
 
-    @raises(exception.SourceNotFound)
     def test_get_mgr_SourceNotFound_multi(self):
         """GFAL2 (RSE/PROTOCOLS): Get multiple files from storage providing LFNs and PFNs (SourceNotFound)"""
-        self.mtc.test_get_mgr_SourceNotFound_multi()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_get_mgr_SourceNotFound_multi()
 
-    @raises(exception.SourceNotFound)
     def test_get_mgr_SourceNotFound_single_lfn(self):
         """GFAL2 (RSE/PROTOCOLS): Get a single file from storage providing LFN (SourceNotFound)"""
-        self.mtc.test_get_mgr_SourceNotFound_single_lfn()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_get_mgr_SourceNotFound_single_lfn()
 
-    @raises(exception.SourceNotFound)
     def test_get_mgr_SourceNotFound_single_pfn(self):
         """GFAL2 (RSE/PROTOCOLS): Get a single file from storage providing PFN (SourceNotFound)"""
-        self.mtc.test_get_mgr_SourceNotFound_single_pfn()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_get_mgr_SourceNotFound_single_pfn()
 
     # Mgr-Tests: PUT
     def test_put_mgr_ok_multi(self):
@@ -163,25 +175,25 @@ class TestRseGFAL2():
         """GFAL2 (RSE/PROTOCOLS): Put a single file to storage (Success)"""
         self.mtc.test_put_mgr_ok_single()
 
-    @raises(exception.SourceNotFound)
     def test_put_mgr_SourceNotFound_multi(self):
         """GFAL2 (RSE/PROTOCOLS): Put multiple files to storage (SourceNotFound)"""
-        self.mtc.test_put_mgr_SourceNotFound_multi()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_put_mgr_SourceNotFound_multi()
 
-    @raises(exception.SourceNotFound)
     def test_put_mgr_SourceNotFound_single(self):
         """GFAL2 (RSE/PROTOCOLS): Put a single file to storage (SourceNotFound)"""
-        self.mtc.test_put_mgr_SourceNotFound_single()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_put_mgr_SourceNotFound_single()
 
-    @raises(exception.FileReplicaAlreadyExists)
     def test_put_mgr_FileReplicaAlreadyExists_multi(self):
         """GFAL2 (RSE/PROTOCOLS): Put multiple files to storage (FileReplicaAlreadyExists)"""
-        self.mtc.test_put_mgr_FileReplicaAlreadyExists_multi()
+        with pytest.raises(exception.FileReplicaAlreadyExists):
+            self.mtc.test_put_mgr_FileReplicaAlreadyExists_multi()
 
-    @raises(exception.FileReplicaAlreadyExists)
     def test_put_mgr_FileReplicaAlreadyExists_single(self):
         """GFAL2 (RSE/PROTOCOLS): Put a single file to storage (FileReplicaAlreadyExists)"""
-        self.mtc.test_put_mgr_FileReplicaAlreadyExists_single()
+        with pytest.raises(exception.FileReplicaAlreadyExists):
+            self.mtc.test_put_mgr_FileReplicaAlreadyExists_single()
 
     # MGR-Tests: DELETE
     def test_delete_mgr_ok_multi(self):
@@ -192,15 +204,15 @@ class TestRseGFAL2():
         """GFAL2 (RSE/PROTOCOLS): Delete a single file from storage (Success)"""
         self.mtc.test_delete_mgr_ok_single()
 
-    @raises(exception.SourceNotFound)
     def test_delete_mgr_SourceNotFound_multi(self):
         """GFAL2 (RSE/PROTOCOLS): Delete multiple files from storage (SourceNotFound)"""
-        self.mtc.test_delete_mgr_SourceNotFound_multi()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_delete_mgr_SourceNotFound_multi()
 
-    @raises(exception.SourceNotFound)
     def test_delete_mgr_SourceNotFound_single(self):
         """GFAL2 (RSE/PROTOCOLS): Delete a single file from storage (SourceNotFound)"""
-        self.mtc.test_delete_mgr_SourceNotFound_single()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_delete_mgr_SourceNotFound_single()
 
     # MGR-Tests: EXISTS
     def test_exists_mgr_ok_multi(self):
@@ -240,35 +252,35 @@ class TestRseGFAL2():
         """GFAL2 (RSE/PROTOCOLS): Rename a single file on storage using PFN (Success)"""
         self.mtc.test_rename_mgr_ok_single_pfn()
 
-    @raises(exception.FileReplicaAlreadyExists)
     def test_rename_mgr_FileReplicaAlreadyExists_multi(self):
         """GFAL2 (RSE/PROTOCOLS): Rename multiple files on storage (FileReplicaAlreadyExists)"""
-        self.mtc.test_rename_mgr_FileReplicaAlreadyExists_multi()
+        with pytest.raises(exception.FileReplicaAlreadyExists):
+            self.mtc.test_rename_mgr_FileReplicaAlreadyExists_multi()
 
-    @raises(exception.FileReplicaAlreadyExists)
     def test_rename_mgr_FileReplicaAlreadyExists_single_lfn(self):
         """GFAL2 (RSE/PROTOCOLS): Rename a single file on storage using LFN(FileReplicaAlreadyExists)"""
-        self.mtc.test_rename_mgr_FileReplicaAlreadyExists_single_lfn()
+        with pytest.raises(exception.FileReplicaAlreadyExists):
+            self.mtc.test_rename_mgr_FileReplicaAlreadyExists_single_lfn()
 
-    @raises(exception.FileReplicaAlreadyExists)
     def test_rename_mgr_FileReplicaAlreadyExists_single_pfn(self):
         """GFAL2 (RSE/PROTOCOLS): Rename a single file on storage using PFN (FileReplicaAlreadyExists)"""
-        self.mtc.test_rename_mgr_FileReplicaAlreadyExists_single_pfn()
+        with pytest.raises(exception.FileReplicaAlreadyExists):
+            self.mtc.test_rename_mgr_FileReplicaAlreadyExists_single_pfn()
 
-    @raises(exception.SourceNotFound)
     def test_rename_mgr_SourceNotFound_multi(self):
         """GFAL2 (RSE/PROTOCOLS): Rename multiple files on storage (SourceNotFound)"""
-        self.mtc.test_rename_mgr_SourceNotFound_multi()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_rename_mgr_SourceNotFound_multi()
 
-    @raises(exception.SourceNotFound)
     def test_rename_mgr_SourceNotFound_single_lfn(self):
         """GFAL2 (RSE/PROTOCOLS): Rename a single file on storage using LFN (SourceNotFound)"""
-        self.mtc.test_rename_mgr_SourceNotFound_single_lfn()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_rename_mgr_SourceNotFound_single_lfn()
 
-    @raises(exception.SourceNotFound)
     def test_rename_mgr_SourceNotFound_single_pfn(self):
         """GFAL2 (RSE/PROTOCOLS): Rename a single file on storage using PFN (SourceNotFound)"""
-        self.mtc.test_rename_mgr_SourceNotFound_single_pfn()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_rename_mgr_SourceNotFound_single_pfn()
 
     def test_change_scope_mgr_ok_single_lfn(self):
         """GFAL2 (RSE/PROTOCOLS): Change the scope of a single file on storage using LFN (Success)"""
